<br>
<form action="" method="post" enctype="multipart/form-data">
    <div class="form-group">
        <label>product:</label>
        <input required id="product" type="text" class="form-control" name="product" size="30" />
    </div>
    <div class="form-group">
        <label>Stock:</label>
        <input required id="stock" type="text" class="form-control" name="stock" size="30" />
    </div>
    <div class="form-group">
        <label>Description:</label>
        <input required id="description" type="text" class="form-control" name="description" size="30" />
    </div>
    <div class="form-group">
        <label>Purchase price:</label>
        <input required id="purchase_price" type="text" class="form-control" name="purchase_price" size="30" />
    </div>
    <div class="form-group">
        <label>Price sale:</label>
        <input required id="price_sale" type="text" class="form-control" name="price_sale" size="30" />
    </div>
    <div class="form-group">
        <label>Product Image</label>
        <input required id="product_image" type="file" class="form-control" name="product_image" />
    </div>
    <div class="form-group">
        <label></label>
        <button id="send" name="send" class="form-control">Save</button>
    </div>
</form>
<br>
<br>