<br>
<form action="" method="post" enctype="multipart/form-data">

    fields

    <div class="form-group">
        <label></label>
        <button id="send" name="send" class="form-control">Save</button>
    </div>
</form>
<br>
<br>