$def with(table_name)
<br>
<form action="" method="post" enctype="multipart/form-data">
    <input type="hidden" name="primary_key" id="primary_key" value="$table_name.primary_key" />

    fields

    <div class="form-group">
        <label></label>
        <button id="send" name="send" class="form-control">Delete</button>
    </div>
</form>
<br>
<br>