$def with (page)
<!--
    Author: Salvador Hernández Mendoza
    Email: salvadorhm@gmail.com
    https://salvadorhm.github.io/kuorra
    -->
<html>

<head>
    <title>Kuorra base</title>
    <link rel="icon" type="image/png" href="/static/favicon.ico">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="Cache-Control" content="no-cache, max-age=0, no-store, must-revalidate" />
    <link href="../../static/css/bootstrap.css" rel="stylesheet" media="screen">
</head>

<body>
    <div class="navbar navbar-inverse navbar-fixed-top">
        <div class="container">
            <div class="navbar-header">
                <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
                <a class="navbar-brand" href="/">Kuorra base</a>
            </div>
            <div class="collapse navbar-collapse">
                <ul class="nav navbar-nav navbar-right">
                    <li class='active'><a href="/">Kuorra base</a></li>
                    <li><a href="/api_persons?user_hash=12345&action=get"><span class="glyphicon glyphicon-plus"></span> GET All</a></li>
                    <li><a href="/insert"><span class="glyphicon glyphicon-plus"></span> Insert</a></li>
                </ul>
            </div>
        </div>
    </div>
    <div class='container'>
        <br><br> $:page
    </div>

    <div class="navbar  navbar-inverse navbar-fixed-bottom">
        <div class="container">
            <div class="navbar-text pull=left">
                <p> © Kuorra 2017</p>
            </div>

        </div>
    </div>

</body>
<script src="../../static/js/jquery.js"></script>
<script src="../../static/js/bootstrap.js"></script>

</html>