$def with(users)
<h1>users</h1>
<table class="table table-hoview">
    <th>users</th>
    <th>Edit</th>
    <th>Delete</th>

    $for item in users:
    <tr>
        <td><a href='/users/view/$item.username'>$item.username</a></td>
        <td><a href='/users/edit/$item.username'><span class="glyphicon glyphicon-pencil"></span></a></td>
        <td><a href='/users/delete/$item.username'><span class="glyphicon glyphicon-trash"></span></a></td>
    </tr>
</table>
<br>
<br>