$def with(users)
<br>
<form action="" method="post" enctype="multipart/form-data">
    <div class="form-group">
        <label>username</label>
        <input required id="username" type="text" class="form-control"
        name="username" size="30" value="$users.username"/>
    </div>
    <div class="form-group">
        <label>password</label>
        <input required id="password" type="password" class="form-control"
        name="password" size="30" value="$users.password"/>
    </div>

    <div class="form-group">
        <label>privilege</label>
        <select name="privilege" id="privilege" class="form-control">
        $if users.privilege == 0:
            <option selected value=0>Admin</option>
            <option value=1>Guess</option>
         $else:
             <option value=0>Admin</option>
             <option selected value=1>Guess</option>
        </select>
    </div>

    <div class="form-group">
        <label></label>
        <button id="send" name="send" class="form-control"><span class="glyphicon glyphicon-pencil"></span>  Edit</button>
    </div>
</form>
<br>
<br>